msolve: Multivariate polynomial system solver
=============================================

Description
-----------

Open source C library implementing computer algebra algorithms for solving
polynomial systems (with rational coefficients or coefficients in a prime field).

License
-------

GPL v2+

Upstream Contact
----------------

https://github.com/algebraic-solving/msolve

Upstream does not make source tarballs.
We make tarballs from the fork https://github.com/mkoeppe/msolve (branch 0.4.4+sage)
